﻿using Syncfusion.UI.Xaml.Charts;
using System;
using System.Collections.Generic;
using System.Globalization;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;

namespace TrackBallInfos
{
    public class CustomTrackBallBehavior : ChartTrackBallBehavior
    {

        /// <summary>
        /// Label format for track ball label.
        /// </summary>
        public string TrackBallLabelFormat
        {
            get { return (string)GetValue(TrackBallLabelFormatProperty); }
            set { SetValue(TrackBallLabelFormatProperty, value); }
        }

        // Using a DependencyProperty as the backing store for TrackBallLabelFormat.  This enables animation, styling, binding, etc...
        public static readonly DependencyProperty TrackBallLabelFormatProperty =
            DependencyProperty.Register("TrackBallLabelFormat", typeof(string), typeof(CustomTrackBallBehavior), new PropertyMetadata(null));


        /// <summary>
        /// To denote which value to be shown in track ball labels.
        /// </summary>
        public TrackBallValue TrackBallValue
        {
            get { return (TrackBallValue)GetValue(TrackBallValueProperty); }
            set { SetValue(TrackBallValueProperty, value); }
        }

        // Using a DependencyProperty as the backing store for TrackBallValue.  This enables animation, styling, binding, etc...
        public static readonly DependencyProperty TrackBallValueProperty =
            DependencyProperty.Register("TrackBallValue", typeof(TrackBallValue), typeof(CustomTrackBallBehavior), new PropertyMetadata(TrackBallValue.Y));


        public CustomTrackBallBehavior()
        {

        }

        /// <summary>
        /// To add track ball labels in the track line
        /// </summary>
        /// <param name="obj">Chart point info</param>
        /// <param name="verticalAlignment">Horizontal alignment of track ball label</param>
        /// <param name="horizontalAlignment">Vertical alignment of track ball label</param>
        /// <param name="template">Track ball label template</param>
        /// <param name="x">x-position of track ball label</param>
        /// <param name="y">y-position of track ball label</param>
        protected override void AddLabel(object obj, ChartAlignment verticalAlignment, ChartAlignment horizontalAlignment, DataTemplate template, double x, double y)
        {
            ChartPointInfo pointInfo = obj as ChartPointInfo;
            if (TrackBallValue == TrackBallValue.X)
                pointInfo.ValueY = pointInfo.ValueX;
            else if (TrackBallValue == TrackBallValue.XY)
            {
                var valY = (TrackBallLabelFormat == null) ? pointInfo.ValueY :
                    Convert.ToDouble(pointInfo.ValueY).ToString(TrackBallLabelFormat, CultureInfo.CurrentCulture);
                var totalVal = String.Concat(pointInfo.ValueX + " : " + valY);
                pointInfo.ValueY = totalVal;
            }
            else if (TrackBallValue == TrackBallValue.Y)
            {
                pointInfo.ValueY = (TrackBallLabelFormat == null) ? pointInfo.ValueY :
                    Convert.ToDouble(pointInfo.ValueY).ToString(TrackBallLabelFormat, CultureInfo.CurrentCulture);
            }
            base.AddLabel(pointInfo, verticalAlignment, horizontalAlignment, template, x, y);
        }
    }

}
